package javax.swing.plaf.basic;

import javax.swing.AbstractAction;
import java.beans.PropertyVetoException;
import java.awt.Point;
import java.awt.Insets;
import java.awt.FocusTraversalPolicy;
import java.awt.Container;
import java.awt.KeyboardFocusManager;
import javax.swing.SortingFocusTraversalPolicy;
import java.awt.event.ActionEvent;
import java.awt.Component;
import javax.swing.JInternalFrame;
import sun.swing.UIAction;
import javax.swing.DefaultDesktopManager;
import java.beans.PropertyChangeEvent;
import java.awt.Dimension;
import java.awt.Graphics;
import sun.swing.DefaultLookup;
import javax.swing.InputMap;
import javax.swing.SwingUtilities;
import javax.swing.LookAndFeel;
import javax.swing.UIManager;
import javax.swing.plaf.UIResource;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import javax.swing.KeyStroke;
import javax.swing.DesktopManager;
import javax.swing.JDesktopPane;
import java.beans.PropertyChangeListener;
import javax.swing.plaf.DesktopPaneUI;

public class BasicDesktopPaneUI extends DesktopPaneUI
{
    private static final BasicDesktopPaneUI.Actions SHARED_ACTION;
    private BasicDesktopPaneUI.Handler handler;
    private PropertyChangeListener pcl;
    protected JDesktopPane desktop;
    protected DesktopManager desktopManager;
    @Deprecated
    protected KeyStroke minimizeKey;
    @Deprecated
    protected KeyStroke maximizeKey;
    @Deprecated
    protected KeyStroke closeKey;
    @Deprecated
    protected KeyStroke navigateKey;
    @Deprecated
    protected KeyStroke navigateKey2;
    
    public static ComponentUI createUI(JComponent component) {
        return new BasicDesktopPaneUI();
    }
    
    public BasicDesktopPaneUI() {
    }
    
    @Override
    public void installUI(JComponent component) {
        this.desktop = (JDesktopPane)component;
        this.installDefaults();
        this.installDesktopManager();
        this.installListeners();
        this.installKeyboardActions();
    }
    
    @Override
    public void uninstallUI(JComponent component) {
        this.uninstallKeyboardActions();
        this.uninstallListeners();
        this.uninstallDesktopManager();
        this.uninstallDefaults();
        this.desktop = null;
        this.handler = null;
    }
    
    protected void installDefaults() {
        if (this.desktop.getBackground() == null || this.desktop.getBackground() instanceof UIResource) {
            this.desktop.setBackground(UIManager.getColor("Desktop.background"));
        }
        LookAndFeel.installProperty(this.desktop, "opaque", Boolean.TRUE);
    }
    
    protected void uninstallDefaults() {
    }
    
    protected void installListeners() {
        this.pcl = this.createPropertyChangeListener();
        this.desktop.addPropertyChangeListener(this.pcl);
    }
    
    protected void uninstallListeners() {
        this.desktop.removePropertyChangeListener(this.pcl);
        this.pcl = null;
    }
    
    protected void installDesktopManager() {
        this.desktopManager = this.desktop.getDesktopManager();
        if (this.desktopManager == null) {
            this.desktopManager = new BasicDesktopPaneUI.BasicDesktopManager();
            this.desktop.setDesktopManager(this.desktopManager);
        }
    }
    
    protected void uninstallDesktopManager() {
        if ((this.desktop.getDesktopManager() instanceof UIResource)) {
            this.desktop.setDesktopManager(null);
        }
        this.desktopManager = null;
    }
    
    protected void installKeyboardActions() {
        InputMap inputMap = this.getInputMap(2);
        if (inputMap != null) {
            SwingUtilities.replaceUIInputMap(this.desktop, 2, inputMap);
        }
        InputMap inputMap2 = this.getInputMap(1);
        if (inputMap2 != null) {
            SwingUtilities.replaceUIInputMap(this.desktop, 1, inputMap2);
        }
        LazyActionMap.installLazyActionMap(this.desktop, BasicDesktopPaneUI.class, "DesktopPane.actionMap");
        this.registerKeyboardActions();
    }
    
    protected void registerKeyboardActions() {
    }
    
    protected void unregisterKeyboardActions() {
    }
    
    InputMap getInputMap(int n) {
        if (n == 2) {
            return this.createInputMap(n);
        }
        if (n == 1) {
            return (InputMap)DefaultLookup.get(this.desktop, this, "Desktop.ancestorInputMap");
        }
        return null;
    }
    
    InputMap createInputMap(int n) {
        if (n == 2) {
            Object[] keys = (Object[])(Object[])DefaultLookup.get(this.desktop, this, "Desktop.windowBindings");
            if (keys != null) {
                return LookAndFeel.makeComponentInputMap(this.desktop, keys);
            }
        }
        return null;
    }
    
    static void loadActionMap(LazyActionMap lazyActionMap) {
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.RESTORE));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.CLOSE));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.MOVE));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.RESIZE));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.LEFT));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.SHRINK_LEFT));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.RIGHT));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.SHRINK_RIGHT));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.UP));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.SHRINK_UP));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.DOWN));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.SHRINK_DOWN));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.ESCAPE));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.MINIMIZE));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.MAXIMIZE));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.NEXT_FRAME));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.PREVIOUS_FRAME));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.NAVIGATE_NEXT));
        lazyActionMap.put(new BasicDesktopPaneUI.Actions(BasicDesktopPaneUI.Actions.NAVIGATE_PREVIOUS));
    }
    
    protected void uninstallKeyboardActions() {
        this.unregisterKeyboardActions();
        SwingUtilities.replaceUIInputMap(this.desktop, 2, null);
        SwingUtilities.replaceUIInputMap(this.desktop, 1, null);
        SwingUtilities.replaceUIActionMap(this.desktop, null);
    }
    
    @Override
    public void paint(Graphics graphics, JComponent component) {
    }
    
    @Override
    public Dimension getPreferredSize(JComponent component) {
        return null;
    }
    
    @Override
    public Dimension getMinimumSize(JComponent component) {
        return new Dimension(0, 0);
    }
    
    @Override
    public Dimension getMaximumSize(JComponent component) {
        return new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE);
    }
    
    protected PropertyChangeListener createPropertyChangeListener() {
        return this.getHandler();
    }
    
    private BasicDesktopPaneUI.Handler getHandler() {
        if (this.handler == null) {
            this.handler = new BasicDesktopPaneUI.Handler();
        }
        return this.handler;
    }
    
    static {
        SHARED_ACTION = new BasicDesktopPaneUI.Actions();
    }
    
    private class Handler implements PropertyChangeListener
    {
        @Override
        public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
            if ("desktopManager" == propertyChangeEvent.getPropertyName()) {
                BasicDesktopPaneUI.this.installDesktopManager();
            }
        }
    }
    
    private class BasicDesktopManager extends DefaultDesktopManager implements UIResource
    {
    }
    
    private static class Actions extends UIAction
    {
        private static String CLOSE;
        private static String ESCAPE;
        private static String MAXIMIZE;
        private static String MINIMIZE;
        private static String MOVE;
        private static String RESIZE;
        private static String RESTORE;
        private static String LEFT;
        private static String RIGHT;
        private static String UP;
        private static String DOWN;
        private static String SHRINK_LEFT;
        private static String SHRINK_RIGHT;
        private static String SHRINK_UP;
        private static String SHRINK_DOWN;
        private static String NEXT_FRAME;
        private static String PREVIOUS_FRAME;
        private static String NAVIGATE_NEXT;
        private static String NAVIGATE_PREVIOUS;
        private final int MOVE_RESIZE_INCREMENT = 10;
        private static boolean moving;
        private static boolean resizing;
        private static JInternalFrame sourceFrame;
        private static Component focusOwner;
        
        Actions() {
            super(null);
        }
        
        Actions(String name) {
            super(name);
        }
        
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            JDesktopPane desktopPane = (JDesktopPane)actionEvent.getSource();
            String name = this.getName();
            if (BasicDesktopPaneUI.Actions.CLOSE == name || BasicDesktopPaneUI.Actions.MAXIMIZE == name || BasicDesktopPaneUI.Actions.MINIMIZE == name || BasicDesktopPaneUI.Actions.RESTORE == name) {
                this.setState(desktopPane, name);
            }
            else if (BasicDesktopPaneUI.Actions.ESCAPE == name) {
                if (BasicDesktopPaneUI.Actions.sourceFrame == desktopPane.getSelectedFrame() && BasicDesktopPaneUI.Actions.focusOwner != null) {
                    BasicDesktopPaneUI.Actions.focusOwner.requestFocus();
                }
                BasicDesktopPaneUI.Actions.moving = false;
                BasicDesktopPaneUI.Actions.resizing = false;
                BasicDesktopPaneUI.Actions.sourceFrame = null;
                BasicDesktopPaneUI.Actions.focusOwner = null;
            }
            else if (BasicDesktopPaneUI.Actions.MOVE == name || BasicDesktopPaneUI.Actions.RESIZE == name) {
                BasicDesktopPaneUI.Actions.sourceFrame = desktopPane.getSelectedFrame();
                if (BasicDesktopPaneUI.Actions.sourceFrame == null) {
                    return;
                }
                BasicDesktopPaneUI.Actions.moving = (name == BasicDesktopPaneUI.Actions.MOVE);
                BasicDesktopPaneUI.Actions.resizing = (name == BasicDesktopPaneUI.Actions.RESIZE);
                BasicDesktopPaneUI.Actions.focusOwner = KeyboardFocusManager.getCurrentKeyboardFocusManager().getFocusOwner();
                if (!SwingUtilities.isDescendingFrom(BasicDesktopPaneUI.Actions.focusOwner, BasicDesktopPaneUI.Actions.sourceFrame)) {
                    BasicDesktopPaneUI.Actions.focusOwner = null;
                }
                BasicDesktopPaneUI.Actions.sourceFrame.requestFocus();
            }
            else if (BasicDesktopPaneUI.Actions.LEFT == name || BasicDesktopPaneUI.Actions.RIGHT == name || BasicDesktopPaneUI.Actions.UP == name || BasicDesktopPaneUI.Actions.DOWN == name || BasicDesktopPaneUI.Actions.SHRINK_RIGHT == name || BasicDesktopPaneUI.Actions.SHRINK_LEFT == name || BasicDesktopPaneUI.Actions.SHRINK_UP == name || BasicDesktopPaneUI.Actions.SHRINK_DOWN == name) {
                JInternalFrame selectedFrame = desktopPane.getSelectedFrame();
                if (BasicDesktopPaneUI.Actions.sourceFrame == null || selectedFrame != BasicDesktopPaneUI.Actions.sourceFrame || KeyboardFocusManager.getCurrentKeyboardFocusManager().getFocusOwner() != BasicDesktopPaneUI.Actions.sourceFrame) {
                    return;
                }
                Insets insets = UIManager.getInsets("Desktop.minOnScreenInsets");
                Dimension size = selectedFrame.getSize();
                Dimension minimumSize = selectedFrame.getMinimumSize();
                int width = desktopPane.getWidth();
                int height = desktopPane.getHeight();
                Point location = selectedFrame.getLocation();
                if (BasicDesktopPaneUI.Actions.LEFT == name) {
                    if (BasicDesktopPaneUI.Actions.moving) {
                        selectedFrame.setLocation((location.x + size.width - 10 < insets.right) ? (-size.width + insets.right) : (location.x - 10), location.y);
                    }
                    else if (BasicDesktopPaneUI.Actions.resizing) {
                        selectedFrame.setLocation(location.x - 10, location.y);
                        selectedFrame.setSize(size.width + 10, size.height);
                    }
                }
                else if (BasicDesktopPaneUI.Actions.RIGHT == name) {
                    if (BasicDesktopPaneUI.Actions.moving) {
                        selectedFrame.setLocation((location.x + 10 > width - insets.left) ? (width - insets.left) : (location.x + 10), location.y);
                    }
                    else if (BasicDesktopPaneUI.Actions.resizing) {
                        selectedFrame.setSize(size.width + 10, size.height);
                    }
                }
                else if (BasicDesktopPaneUI.Actions.UP == name) {
                    if (BasicDesktopPaneUI.Actions.moving) {
                        selectedFrame.setLocation(location.x, (location.y + size.height - 10 < insets.bottom) ? (-size.height + insets.bottom) : (location.y - 10));
                    }
                    else if (BasicDesktopPaneUI.Actions.resizing) {
                        selectedFrame.setLocation(location.x, location.y - 10);
                        selectedFrame.setSize(size.width, size.height + 10);
                    }
                }
                else if (BasicDesktopPaneUI.Actions.DOWN == name) {
                    if (BasicDesktopPaneUI.Actions.moving) {
                        selectedFrame.setLocation(location.x, (location.y + 10 > height - insets.top) ? (height - insets.top) : (location.y + 10));
                    }
                    else if (BasicDesktopPaneUI.Actions.resizing) {
                        selectedFrame.setSize(size.width, size.height + 10);
                    }
                }
                else if (BasicDesktopPaneUI.Actions.SHRINK_LEFT == name && BasicDesktopPaneUI.Actions.resizing) {
                    int n5;
                    if (minimumSize.width < size.width - 10) {
                        n5 = 10;
                    }
                    else {
                        n5 = size.width - minimumSize.width;
                    }
                    if (location.x + size.width - n5 < insets.left) {
                        n5 = location.x + size.width - insets.left;
                    }
                    selectedFrame.setSize(size.width - n5, size.height);
                }
                else if (BasicDesktopPaneUI.Actions.SHRINK_RIGHT == name && BasicDesktopPaneUI.Actions.resizing) {
                    int n4;
                    if (minimumSize.width < size.width - 10) {
                        n4 = 10;
                    }
                    else {
                        n4 = size.width - minimumSize.width;
                    }
                    if (location.x + n4 > width - insets.right) {
                        n4 = width - insets.right - location.x;
                    }
                    selectedFrame.setLocation(location.x + n4, location.y);
                    selectedFrame.setSize(size.width - n4, size.height);
                }
                else if (BasicDesktopPaneUI.Actions.SHRINK_UP == name && BasicDesktopPaneUI.Actions.resizing) {
                    int n3;
                    if (minimumSize.height < size.height - 10) {
                        n3 = 10;
                    }
                    else {
                        n3 = size.height - minimumSize.height;
                    }
                    if (location.y + size.height - n3 < insets.bottom) {
                        n3 = location.y + size.height - insets.bottom;
                    }
                    selectedFrame.setSize(size.width, size.height - n3);
                }
                else if (BasicDesktopPaneUI.Actions.SHRINK_DOWN == name && BasicDesktopPaneUI.Actions.resizing) {
                    int n2;
                    if (minimumSize.height < size.height - 10) {
                        n2 = 10;
                    }
                    else {
                        n2 = size.height - minimumSize.height;
                    }
                    if (location.y + n2 > height - insets.top) {
                        n2 = height - insets.top - location.y;
                    }
                    selectedFrame.setLocation(location.x, location.y + n2);
                    selectedFrame.setSize(size.width, size.height - n2);
                }
            }
            else if (BasicDesktopPaneUI.Actions.NEXT_FRAME == name || BasicDesktopPaneUI.Actions.PREVIOUS_FRAME == name) {
                desktopPane.selectFrame(name == BasicDesktopPaneUI.Actions.NEXT_FRAME);
            }
            else if (BasicDesktopPaneUI.Actions.NAVIGATE_NEXT == name || BasicDesktopPaneUI.Actions.NAVIGATE_PREVIOUS == name) {
                boolean n = true;
                if (BasicDesktopPaneUI.Actions.NAVIGATE_PREVIOUS == name) {
                    n = false;
                }
                Container focusCycleRootAncestor = desktopPane.getFocusCycleRootAncestor();
                if (focusCycleRootAncestor != null) {
                    FocusTraversalPolicy focusTraversalPolicy = focusCycleRootAncestor.getFocusTraversalPolicy();
                    if (focusTraversalPolicy != null && focusTraversalPolicy instanceof SortingFocusTraversalPolicy) {
                        SortingFocusTraversalPolicy sortingFocusTraversalPolicy = (SortingFocusTraversalPolicy)focusTraversalPolicy;
                        int implicitDownCycleTraversal = sortingFocusTraversalPolicy.getImplicitDownCycleTraversal();
                        try {
                            sortingFocusTraversalPolicy.setImplicitDownCycleTraversal(false);
                            if (!(n == 0)) {
                                KeyboardFocusManager.getCurrentKeyboardFocusManager().focusNextComponent(desktopPane);
                            }
                            else {
                                KeyboardFocusManager.getCurrentKeyboardFocusManager().focusPreviousComponent(desktopPane);
                            }
                        }
                        finally {
                            sortingFocusTraversalPolicy.setImplicitDownCycleTraversal((boolean)implicitDownCycleTraversal);
                        }
                    }
                }
            }
        }
        
        private void setState(JDesktopPane desktopPane, String s) {
            if (s == BasicDesktopPaneUI.Actions.CLOSE) {
                JInternalFrame selectedFrame4 = desktopPane.getSelectedFrame();
                if (selectedFrame4 == null) {
                    return;
                }
                selectedFrame4.doDefaultCloseAction();
            }
            else if (s == BasicDesktopPaneUI.Actions.MAXIMIZE) {
                JInternalFrame selectedFrame3 = desktopPane.getSelectedFrame();
                if (selectedFrame3 == null) {
                    return;
                }
                if (!selectedFrame3.isMaximum()) {
                    if (selectedFrame3.isIcon()) {
                        try {
                            selectedFrame3.setIcon(false);
                            selectedFrame3.setMaximum(true);
                        }
                        catch (PropertyVetoException ex4) {}
                    }
                    else {
                        try {
                            selectedFrame3.setMaximum(true);
                        }
                        catch (PropertyVetoException ex3) {}
                    }
                }
            }
            else if (s == BasicDesktopPaneUI.Actions.MINIMIZE) {
                JInternalFrame selectedFrame2 = desktopPane.getSelectedFrame();
                if (selectedFrame2 == null) {
                    return;
                }
                if (!selectedFrame2.isIcon()) {
                    try {
                        selectedFrame2.setIcon(true);
                    }
                    catch (PropertyVetoException ex2) {}
                }
            }
            else if (s == BasicDesktopPaneUI.Actions.RESTORE) {
                JInternalFrame selectedFrame = desktopPane.getSelectedFrame();
                if (selectedFrame == null) {
                    return;
                }
                try {
                    if (selectedFrame.isIcon()) {
                        selectedFrame.setIcon(false);
                    }
                    else if (selectedFrame.isMaximum()) {
                        selectedFrame.setMaximum(false);
                    }
                    selectedFrame.setSelected(true);
                }
                catch (PropertyVetoException ex) {}
            }
        }
        
        public boolean isEnabled(Object o) {
            if ((o instanceof JDesktopPane)) {
                JDesktopPane desktopPane = (JDesktopPane)o;
                String name = this.getName();
                if (name == BasicDesktopPaneUI.Actions.NEXT_FRAME || name == BasicDesktopPaneUI.Actions.PREVIOUS_FRAME) {
                    return true;
                }
                JInternalFrame selectedFrame = desktopPane.getSelectedFrame();
                if (selectedFrame == null) {
                    return false;
                }
                if (name == BasicDesktopPaneUI.Actions.CLOSE) {
                    return selectedFrame.isClosable();
                }
                if (name == BasicDesktopPaneUI.Actions.MINIMIZE) {
                    return selectedFrame.isIconifiable();
                }
                return name != BasicDesktopPaneUI.Actions.MAXIMIZE || selectedFrame.isMaximizable();
            }
            else {
                return false;
            }
        }
        
        static void access$2200(BasicDesktopPaneUI.Actions actions, JDesktopPane desktopPane, String s) {
            actions.setState(desktopPane, s);
        }
        
        static {
            BasicDesktopPaneUI.Actions.CLOSE = "close";
            BasicDesktopPaneUI.Actions.ESCAPE = "escape";
            BasicDesktopPaneUI.Actions.MAXIMIZE = "maximize";
            BasicDesktopPaneUI.Actions.MINIMIZE = "minimize";
            BasicDesktopPaneUI.Actions.MOVE = "move";
            BasicDesktopPaneUI.Actions.RESIZE = "resize";
            BasicDesktopPaneUI.Actions.RESTORE = "restore";
            BasicDesktopPaneUI.Actions.LEFT = "left";
            BasicDesktopPaneUI.Actions.RIGHT = "right";
            BasicDesktopPaneUI.Actions.UP = "up";
            BasicDesktopPaneUI.Actions.DOWN = "down";
            BasicDesktopPaneUI.Actions.SHRINK_LEFT = "shrinkLeft";
            BasicDesktopPaneUI.Actions.SHRINK_RIGHT = "shrinkRight";
            BasicDesktopPaneUI.Actions.SHRINK_UP = "shrinkUp";
            BasicDesktopPaneUI.Actions.SHRINK_DOWN = "shrinkDown";
            BasicDesktopPaneUI.Actions.NEXT_FRAME = "selectNextFrame";
            BasicDesktopPaneUI.Actions.PREVIOUS_FRAME = "selectPreviousFrame";
            BasicDesktopPaneUI.Actions.NAVIGATE_NEXT = "navigateNext";
            BasicDesktopPaneUI.Actions.NAVIGATE_PREVIOUS = "navigatePrevious";
            BasicDesktopPaneUI.Actions.moving = false;
            BasicDesktopPaneUI.Actions.resizing = false;
            BasicDesktopPaneUI.Actions.sourceFrame = null;
            BasicDesktopPaneUI.Actions.focusOwner = null;
        }
    }
    
    protected class OpenAction extends AbstractAction
    {
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            BasicDesktopPaneUI.Actions.access$2200(BasicDesktopPaneUI.SHARED_ACTION, (JDesktopPane)actionEvent.getSource(), BasicDesktopPaneUI.Actions.RESTORE);
        }
        
        @Override
        public boolean isEnabled() {
            return true;
        }
    }
    
    protected class CloseAction extends AbstractAction
    {
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            BasicDesktopPaneUI.Actions.access$2200(BasicDesktopPaneUI.SHARED_ACTION, (JDesktopPane)actionEvent.getSource(), BasicDesktopPaneUI.Actions.CLOSE);
        }
        
        @Override
        public boolean isEnabled() {
            JInternalFrame selectedFrame = BasicDesktopPaneUI.this.desktop.getSelectedFrame();
            return selectedFrame != null && selectedFrame.isClosable();
        }
    }
    
    protected class MinimizeAction extends AbstractAction
    {
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            BasicDesktopPaneUI.Actions.access$2200(BasicDesktopPaneUI.SHARED_ACTION, (JDesktopPane)actionEvent.getSource(), BasicDesktopPaneUI.Actions.MINIMIZE);
        }
        
        @Override
        public boolean isEnabled() {
            JInternalFrame selectedFrame = BasicDesktopPaneUI.this.desktop.getSelectedFrame();
            return selectedFrame != null && selectedFrame.isIconifiable();
        }
    }
    
    protected class MaximizeAction extends AbstractAction
    {
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            BasicDesktopPaneUI.Actions.access$2200(BasicDesktopPaneUI.SHARED_ACTION, (JDesktopPane)actionEvent.getSource(), BasicDesktopPaneUI.Actions.MAXIMIZE);
        }
        
        @Override
        public boolean isEnabled() {
            JInternalFrame selectedFrame = BasicDesktopPaneUI.this.desktop.getSelectedFrame();
            return selectedFrame != null && selectedFrame.isMaximizable();
        }
    }
    
    protected class NavigateAction extends AbstractAction
    {
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            ((JDesktopPane)actionEvent.getSource()).selectFrame(true);
        }
        
        @Override
        public boolean isEnabled() {
            return true;
        }
    }
}
